@@ -2,7 +2,7 @@
 -- Author: Chris Rowett (crowett@gmail.com), November 2016
 -- Use F12 to save a screenshot
 
-local build     = 82
+local build     = 84
 local g         = golly()
 -- require "gplus.strict"
 local gp        = require "gplus"
@@ -174,8 +174,8 @@ local options = {
     showoptions   = false,
     confirming    = false,
     comboscore    = 1,
-    soundvol      = 1,
-    musicvol      = 1,
+    soundvol      = 100,
+    musicvol      = 70,
     fullscreen    = 0
 }
 
@@ -234,8 +234,8 @@ local messages = {
     ["askleft"]    = { text = "Click or Enter to Confirm", size = 10, color = colors.white },
     ["askright"]   = { text = "Right Click to Cancel", size = 10, color = colors.white },
     ["resume"]     = { text = "Click or Enter to continue", size = 10, color = colors.white },
-    ["focus"]      = { text = "Move mouse onto overlay to continue", size = 10, color = colors.white },
-    ["manfocus"]   = { text = "Move mouse onto overlay and", size = 10, color = colors.white },
+    ["focus"]      = { text = "Move mouse onto game window to continue", size = 10, color = colors.white },
+    ["manfocus"]   = { text = "Move mouse onto game window and", size = 10, color = colors.white },
     ["quitgame"]   = { text = "Right Click to quit game", size = 10, color = colors.white },
     ["option"]     = { text = "Tab for Game Settings", size = 10, color = colors.white },
     ["restart"]    = { text = "Click or Enter to start again", size = 10, color = colors.white },
@@ -300,7 +300,7 @@ local music = {
     fade         = 1,
     faderate     = -0.01,
     gameovertime = 1000 * 64,
-    folder       = "oplus/sounds/breakout/"
+    folder       = "sounds/breakout/"
 }
 
 --------------------------------------------------------------------------------
@@ -407,13 +407,13 @@ end
 --------------------------------------------------------------------------------
 
 local function soundstate(sound)
-    return ov("sound state "..music.folder..sound..".ogg")
+    return g.sound("state", music.folder..sound..".ogg")
 end
 
 --------------------------------------------------------------------------------
 
 local function setvolume(sound, vol)
-    ov("sound volume "..music.folder..sound..".ogg "..vol)
+    g.sound("volume", music.folder..sound..".ogg", vol)
 end
 
 --------------------------------------------------------------------------------
@@ -435,14 +435,14 @@ end
 --------------------------------------------------------------------------------
 
 local function stopallsound()
-    ov("sound stop")
+    g.sound("stop")
 end
 
 --------------------------------------------------------------------------------
 
 local function stopmusic()
     if music.currenttrack ~= "" then
-        ov("sound stop "..music.folder..music.currenttrack..".ogg")
+        g.sound("stop", music.folder..music.currenttrack..".ogg")
     end
 end
 --------------------------------------------------------------------------------
@@ -451,9 +451,9 @@ local function playsound(name, loop)
     if options.soundvol > 0 then
         loop = loop or false
         if loop then
-            ov("sound loop "..music.folder..name..".ogg "..(options.soundvol / 100))
+            g.sound("loop", music.folder..name..".ogg", options.soundvol / 100)
         else
-            ov("sound play "..music.folder..name..".ogg "..(options.soundvol / 100))
+            g.sound("play", music.folder..name..".ogg", options.soundvol / 100)
         end
     end
 end
@@ -465,9 +465,9 @@ local function playmusic(name, loop)
     stopmusic()
     music.currenttrack = name
     if loop then
-        ov("sound loop "..music.folder..name..".ogg "..(options.musicvol / 100))
+        g.sound("loop", music.folder..name..".ogg", options.musicvol / 100)
     else
-        ov("sound play "..music.folder..name..".ogg "..(options.musicvol / 100))
+        g.sound("play", music.folder..name..".ogg", options.musicvol / 100)
     end
 end
 
@@ -620,7 +620,11 @@ local function notify(message, flag)
     -- create the text clip
     updatemessage("notify", notification.message)
     if notification.current ~= 0 then
-        notification.current = notification.trans
+        if notification.current > notification.duration - notification.trans then
+            notification.current = notification.duration - notification.current
+        else
+            notification.current = notification.trans
+        end
     end
 end
 
@@ -653,7 +657,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawparticles()
-    ov("blend 1")
+    ov("blend 2")
     local xy = {"fill"}
     local m = 2
     local color = {"rgba", 0, 0, 0, -1}
@@ -733,7 +737,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawpoints()
-    ov("blend 1")
+    ov("blend 2")
     for i = 1, #points do
         local item = points[i]
         -- check if item is still alive
@@ -771,7 +775,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawfadingbricks(pass, xoff, yoff)
-    ov("blend 1")
+    ov("blend 2")
     -- get the list of fading bricks
     local fading = brick.fading
     local fadecols = brick.fadecols
@@ -865,7 +869,7 @@ local function drawbricks()
     for pass = startpass, 2 do
         drawfadingbricks(pass, xoff, yoff)
         if pass == 1 then
-            ov("blend 1")
+            ov("blend 2")
             ovt(shadow.color)
         else
             ov("blend 0")
@@ -893,7 +897,7 @@ end
 
 local function drawball()
     local oldwidth = ov("lineoption width "..(ball.size // 2))
-    ov("blend 1")
+    ov("blend 2")
     if options.showshadows == 1 then
         ovt(shadow.color)
         ov("ellipse "..(((ball.x - ball.size // 2) + shadow.x) // 1 | 0).." "..(((ball.y - ball.size // 2) + shadow.y) // 1 | 0).." "..ball.size.." "..ball.size)
@@ -910,7 +914,7 @@ end
 
 local function drawbat(alpha)
     alpha = alpha or 256
-    ov("blend 1")
+    ov("blend 2")
     if options.showshadows == 1 then
         shadow.fadecolor[5] = alpha // 2
         ovt(shadow.fadecolor)
@@ -1200,7 +1204,7 @@ local function pausegame(paused)
                 music.faderate  = -0.05
             else
                 music.faderate = 0.05
-                ov("sound resume")
+                g.sound("resume")
             end
         end
     end
@@ -1215,7 +1219,7 @@ local function updatemusic()
                 music.fade = music.fade + music.faderate
                 if music.fade <= 0 then
                     music.fade = 0
-                    ov("sound pause")
+                    g.sound("pause")
                 else
                     setvolume(music.currenttrack, (options.musicvol * music.fade / 100))
                 end
@@ -1368,7 +1372,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawscoreline()
-    ov("blend 1")
+    ov("blend 2")
     drawtextclip("score", 4, 4, text.alignleft)
     drawtextclip("balls", -4, 4, text.alignright)
     drawtextclip("high", 0, 4, text.aligncenter)
@@ -1398,7 +1402,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawgameover()
-    ov("blend 1")
+    ov("blend 2")
     if game.newhigh then
         local highscorew = drawtextclip("newhigh", 0, ht / 2 + 96 * text.fontscale, text.aligncenter)
         createparticles(edgegapl + (wd / 2 + highscorew / 2), (ht / 2 + 96 * text.fontscale), highscorew, 1, particle.highparticles)
@@ -1422,7 +1426,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawlevelcomplete()
-    ov("blend 1")
+    ov("blend 2")
     drawtextclip("complete", 0, ht / 2 - 30 * text.fontscale, text.aligncenter)
     drawtextclip("continue", 0, ht / 2 + 30 * text.fontscale, text.aligncenter, nil, true)
     drawtextclip("quitgame", 0, ht / 2 + 52 * text.fontscale, text.aligncenter, nil, true)
@@ -1432,7 +1436,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawbonuscomplete()
-    ov("blend 1")
+    ov("blend 2")
     drawtextclip("bcomplete", 0, ht / 2 - 30 * text.fontscale, text.aligncenter)
 
     local w = drawtextclip("awarded", 0, ht / 2, text.aligncenter)
@@ -1453,7 +1457,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawconfirm()
-    ov("blend 1")
+    ov("blend 2")
     drawtextclip("askquit", 0, ht / 2 - 15 * text.fontscale, text.aligncenter, nil, true)
     drawtextclip("askleft", 0, ht / 2 + 22 * text.fontscale, text.aligncenter, nil, true)
     drawtextclip("askright", 0, ht / 2 + 44 * text.fontscale, text.aligncenter, nil, true)
@@ -1462,7 +1466,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawpause()
-    ov("blend 1")
+    ov("blend 2")
     drawtextclip("pause", 0, ht / 2 - 15 * text.fontscale, text.aligncenter)
     if game.offoverlay and options.autopause ~= 0 then
         if options.autostart ~= 0 then
@@ -1483,7 +1487,7 @@ end
 --------------------------------------------------------------------------------
 
 local function drawnewball()
-    ov("blend 1")
+    ov("blend 2")
     drawtextclip("newball", 0, ht / 2 + 22 * text.fontscale, text.aligncenter, nil, true)
     drawtextclip("control", 0, ht / 2 + 44 * text.fontscale, text.aligncenter, nil, true)
     drawtextclip("quitgame", 0, ht / 2 + 66 * text.fontscale, text.aligncenter, nil, true)
@@ -1509,7 +1513,7 @@ local function drawtiming(t)
         average = average + timing.times[i]
     end
     average = average / #timing.times
-    local oldblend = ov("blend 1")
+    local oldblend = ov("blend 2")
     updatemessage("ms", string.format("%.1fms", average))
     drawtextclip("ms", -4, 0, text.alignright, text.alignbottom)
     ov("blend "..oldblend)
@@ -1555,7 +1559,7 @@ local function drawoptions()
     local state = {[0] = "off", [1] = "on"}
 
     -- draw header
-    ov("blend 1")
+    ov("blend 2")
     local h = messages["key"].height
     local y = (ht - 14 * h) // 2
     y = drawoption("key", "function", "state", leftx, h, y)
@@ -1845,8 +1849,8 @@ local function breakout()
             -- draw the background
             drawbackground()
 
-            -- check if paused
-            if not game.pause and not options.confirming and not options.showoptions and bonus.current > 0 then
+            -- process next game step unless paused or game finished due to user quit
+            if not game.pause and not options.confirming and not options.showoptions and bonus.current > 0 and game.balls > 0 then
                 -- check for new ball
                 if not game.newball then
                     -- update ball position incrementally
@@ -2093,10 +2097,8 @@ local function breakout()
         -- if game is over destroy bat and display best game combo
         if game.balls == 0 then
             -- destroy bat
-            if game.balls == 0 then
-                createparticles(bat.x + bat.wd, bat.y, bat.wd, bat.ht, particle.lostparticles)
-                bat.fade = shadow.alpha
-            end
+            createparticles(bat.x + bat.wd, bat.y, bat.wd, bat.ht, particle.lostparticles)
+            bat.fade = shadow.alpha
             notify("Best Combo x"..game.maxcombo - 1)
         end
 
