@@ -20,9 +20,10 @@ local rand = math.random
 local floor = math.floor
 local sin = math.sin
 
-local wd, ht  = g.getview(g.getlayer())  -- viewport width and height
+local wd, ht -- viewport width and height (set after hiding scroll bars)
 
-local sound_enabled = false  -- flag if sound available
+-- check if sound is available
+local sound_enabled = g.sound() == 2
 
 local extra_layer = false    -- whether the extra layer was created
 
@@ -32,7 +33,7 @@ local maxzoom = 32
 --------------------------------------------------------------------------------
 
 local function lineartoreal(zoom)
-    return minzoom * math.pow(maxzoom / minzoom, zoom)
+    return minzoom * ((maxzoom / minzoom) ^ zoom)
 end
 
 --------------------------------------------------------------------------------
@@ -43,7 +44,7 @@ local function bezierx(t, x0, x1, x2, x3)
     local aX = x3 - x0 - cX - bX
 
     -- compute x position
-    local x = (aX * math.pow(t, 3)) + (bX * math.pow(t, 2)) + (cX * t) + x0
+    local x = (aX * (t ^ 3)) + (bX * (t ^ 2)) + (cX * t) + x0
     return x
 end
 
@@ -71,21 +72,27 @@ end
 --------------------------------------------------------------------------------
 
 local function animate_credits()
-    -- create the overlay
+    -- get viewport dimensions and create the overlay
+    wd, ht = g.getview(g.getlayer())
     ov("create "..wd.." "..ht)
 
-    -- check if sound is available
-    if (ov("sound") == "2") then sound_enabled = true end
-
     -- create a new layer
     g.addlayer()
     extra_layer = true
     g.setalgo("QuickLife")
 
+    -- create graduated background
+    local bgclip = "bg"
+    create_anim_bg(bgclip)
+    -- draw background now so we won't see the pattern created by g.open
+    ov("blend 0")
+    ovt{"paste", 0, 0, bgclip}
+    ov("update")
+
     -- add the pattern
     g.open("../../Patterns/Life/Guns/golly-ticker.rle")
-    g.setname("Credits")
     g.run(1024)
+    g.setname("Credits")
 
     -- create the cellview
     ov("cellview 1640 -138 1024 1024")
@@ -122,11 +129,13 @@ local function animate_credits()
     ovt{"rgba", 255, 192, 32, 144}
     maketext(bannertext, gollytranslucentclip)
 
-    local creditstext = [[
+    local creditstext1 = [[
+Golly 4.3
+
 © The Golly Gang:
 
-Tom Rokicki, Andrew Trevorrow, Tim Hutton, Dave Greene,
-Jason Summers, Maks Verver, Robert Munafo, Chris Rowett.
+
+
 
 
 
@@ -139,10 +148,10 @@ CREDITS
 The Pioneers
 
 
-John Conway
+
 for creating the Game of Life
 
-Martin Gardner
+
 for popularizing the topic in Scientific American
 
 
@@ -151,25 +160,27 @@ for popularizing the topic in Scientific American
 The Programmers
 
 
-Tom Rokicki
+
 for the complicated stuff
 
-Andrew Trevorrow
+
 for the cross-platform GUI and overlay
 
-Chris Rowett
+
 for rule, rendering and overlay improvements
 
-Tim Hutton
+
 for the RuleTable algorithm
 
-Dave Greene
 
-Jason Summers
 
-Maks Verver
 
-Robert Munafo
+
+
+
+
+
+
 
 
 
@@ -180,6 +191,178 @@ The Beta Testers
 Thanks to all the bug hunters for their
 reports and suggestions, especially:
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+Thanks to
+
+
+
+for the idea behind the HashLife algorithm
+
+
+for QuickLife ideas and non-totalistic algorithm
+
+
+for the B0 rule emulation idea
+
+
+for clever ideas to speed up Larger than Life
+
+
+for inspiring Golly's scripting capabilities
+
+
+for the wonderful Life Lexicon
+
+
+for the brilliant LifeWiki and the online archive
+
+
+for wxWidgets
+
+
+for Python
+
+
+for Lua
+]]
+
+    if sound_enabled then
+        creditstext1 = creditstext1.."\n\nfor cute_sound\n"
+    end
+
+    creditstext1 = creditstext1..
+[[
+
+
+
+
+Pattern Collection
+
+
+
+
+Thanks to everybody who allowed us to distribute
+their fantastic patterns, especially:
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+]]
+
+    local creditstext2 = [[
+
+
+
+
+Tom Rokicki, Andrew Trevorrow, Tim Hutton, Dave Greene, Brenton Bostick,
+Chris Rowett, Jason Summers, Maks Verver, Robert Munafo, Dongook Lee.
+
+
+
+
+
+
+
+
+
+
+
+
+John Conway
+
+
+Martin Gardner
+
+
+
+
+
+
+
+
+Tom Rokicki
+
+
+Andrew Trevorrow
+
+
+Chris Rowett
+
+
+Tim Hutton
+
+
+Dave Greene
+
+Jason Summers
+
+Maks Verver
+
+Robert Munafo
+
+Dongook Lee
+
+
+
+
+
+
+
+
+
+
 Dave Greene
 
 Gabriel Nivasch
@@ -207,57 +390,57 @@ Arie Paap
 
 
 
-Thanks to
+
 
 
 Bill Gosper
-for the idea behind the HashLife algorithm
+
 
 Alan Hensel
-for QuickLife ideas and non-totalistic algorithm
+
 
 David Eppstein
-for the B0 rule emulation idea
+
 
 Adam P. Goucher and Dean Hickerson
-for clever ideas to speed up Larger than Life
+
 
 Eugene Langvagen
-for inspiring Golly's scripting capabilities
+
 
 Stephen Silver
-for the wonderful Life Lexicon
+
 
 Nathaniel Johnston
-for the brilliant LifeWiki and the online archive
+
 
 Julian Smart and all wxWidgets developers
-for wxWidgets
+
 
 Guido van Rossum
-for Python
+
 
 Roberto Ierusalimschy and all Lua developers
-for Lua
+
 ]]
 
     if sound_enabled then
-        creditstext = creditstext.."\nNikolaus Gebhardt @ Ambiera\nfor irrKlang\n"
+        creditstext2 = creditstext2.."\nRandy Gaul\n\n"
     end
 
-    creditstext = creditstext..
+    creditstext2 = creditstext2..
 [[
 
 
 
 
-Pattern Collection
+
 
 
 Dave Greene and Alan Hensel
 
-Thanks to everybody who allowed us to distribute
-their fantastic patterns, especially:
+
+
 
 Nick Gotts
 
@@ -292,20 +475,19 @@ Kenichi Morita
 
     -- start music if sound enabled
     if sound_enabled then
-        ov("sound loop oplus/sounds/overlay-demo/animation.ogg")
-        creditstext = creditstext.."\n\n\n\nMusic\n\n\n'Contentment'\nWritten and performed by Chris Rowett"
+        g.sound("loop", "sounds/credits.ogg", 0.5)
+        creditstext1 = creditstext1.."\n\n\n\nMusic\n\n\n'Contentment'\n"
+        creditstext2 = creditstext2.."\n\n\n\n\n\n\n\nWritten and performed by Chris Rowett"
     end
 
     -- create credits clip
     ov("textoption align center")
     ov("font 14 roman")
 
-    local creditsclip = "credits"
-    local credwidth, credheight = maketext(creditstext, creditsclip, "rgba 128 255 255 255", 2, 2)
-
-    -- create graduated background
-    local bgclip = "bg"
-    create_anim_bg(bgclip)
+    local creditsclip1 = "credits1"
+    local creditsclip2 = "credits2"
+    local credwidth1, credheight1 = maketext(creditstext1, creditsclip1, "rgba 128 255 255 255", 2, 2)
+    local credwidth2, credheight2 = maketext(creditstext2, creditsclip2, "rgba 224 255 255 255", 2, 2)
 
     -- create stars
     local starx = {}
@@ -322,7 +504,8 @@ Kenichi Morita
     local texty
     local running = true
     local credity = ht
-    local creditx = floor((wd - credwidth) / 2)
+    local creditx1 = floor((wd - credwidth1) / 2)
+    local creditx2 = floor((wd - credwidth2) / 2)
     local credpos
     local firsttime = true
     local starttime, endtime
@@ -358,7 +541,8 @@ Kenichi Morita
             create_anim_bg(bgclip)
 
             -- recenter credits text
-            creditx = floor((wd - credwidth) / 2)
+            creditx1 = floor((wd - credwidth1) / 2)
+            creditx2 = floor((wd - credwidth2) / 2)
         end
 
         -- stop when key pressed or mouse button clicked
@@ -462,9 +646,10 @@ Kenichi Morita
 
         -- draw credits
         credpos = floor(credity)
-        pastetext(creditx, credpos, op.identity, creditsclip)
+        pastetext(creditx1, credpos, op.identity, creditsclip1)
+        pastetext(creditx2, credpos, op.identity, creditsclip2)
         credity = credity - .5
-        if credity < -credheight then
+        if credity < -credheight1 and credity < -credheight2 then
             credity = ht
         end
 
@@ -496,7 +681,8 @@ Kenichi Morita
     ov("delete "..exitclip)
     ov("delete "..gollytranslucentclip)
     ov("delete "..gollyopaqueclip)
-    ov("delete "..creditsclip)
+    ov("delete "..creditsclip1)
+    ov("delete "..creditsclip2)
     ov("delete "..bgclip)
 
     -- restore settings
@@ -506,7 +692,7 @@ Kenichi Morita
 
     -- stop music
     if sound_enabled then
-        ov("sound stop")
+        g.sound("stop")
     end
 
     -- delete the layer
