@@ -6,7 +6,7 @@ import golly as g
 r = rect( g.getrect() )
 if r.empty: g.exit("There is no pattern.")
 
-for row in xrange(r.top, r.top + r.height):
-    for col in xrange(r.left, r.left + r.width):
+for row in range(r.top, r.top + r.height):
+    for col in range(r.left, r.left + r.width):
         s = g.getcell(col,row)
-        g.setcell(col, row, (s+s%2)/2-1)
+        g.setcell(col, row, (s+s%2)//2-1)
