@@ -8,8 +8,8 @@ import golly as g
 r = rect( g.getselrect() )
 if r.empty: g.exit("There is no selection.")
 
-for row in xrange(r.top, r.top + r.height):
-    for col in xrange(r.left, r.left + r.width):
+for row in range(r.top, r.top + r.height):
+    for col in range(r.left, r.left + r.width):
         if (col%2) and (row%2):
             g.setcell(col, row, 1+g.getcell(col,row)*2)
         else:
