@@ -17,7 +17,7 @@ prefix = 'HexTurmite'
 turns = [1,2,4,8,16,32]
 
 # http://bytes.com/topic/python/answers/25176-list-subsets
-get_subsets = lambda items: [[x for (pos,x) in zip(range(len(items)), items) if (2**pos) & switches] for switches in range(2**len(items))]
+get_subsets = lambda items: [[x for (pos,x) in zip(list(range(len(items))), items) if (2**pos) & switches] for switches in range(2**len(items))]
 
 # Generate a random rule, while filtering out the dull ones.
 # More to try:
@@ -43,7 +43,7 @@ while True: # (we break out if ok)
         example_spec += '}'
     example_spec += '}'
     is_rule_acceptable = True
-    action_table = eval(string.replace(string.replace(example_spec,'}',']'),'{','['))
+    action_table = eval(example_spec.replace('}',']').replace('{','['))
     # does Turmite change at least one color?
     changes_one = False
     for state in range(ns):
@@ -68,7 +68,7 @@ while True: # (we break out if ok)
     if not turmite_turns:
         is_rule_acceptable = False
     # does turmite get stuck in any subset of states?
-    for subset in get_subsets(range(ns)):
+    for subset in get_subsets(list(range(ns))):
         if len(subset)==0 or len(subset)==ns: # (just an optimisation)
             continue
         leaves_subset = False
@@ -135,7 +135,7 @@ Enter string:
 
 # convert the specification string into action_table[state][color]
 # (convert Mathematica code to Python and run eval)
-action_table = eval(string.replace(string.replace(spec,'}',']'),'{','['))
+action_table = eval(spec.replace('}',']').replace('{','['))
 n_states = len(action_table)
 n_colors = len(action_table[0])
 # (N.B. The terminology 'state' here refers to the internal state of the finite
@@ -191,7 +191,7 @@ would_have_been_facing={
 32:[3,4,5,0,1,2], # u-turn
 }
 
-not_arriving_from_here = [range(n_colors) for i in range(n_dirs)] # (we're going to modify them)
+not_arriving_from_here = [list(range(n_colors)) for i in range(n_dirs)] # (we're going to modify them)
 for color in range(n_colors):
     for state in range(n_states):
         turnset = action_table[state][color][1]
@@ -241,8 +241,8 @@ for s in range(n_states):
                 transitions += [transition]
 
 # default: square is left with no turmite present
-for output_color,inputs in leaving_color_behind.items():
-    transition = [inputs]+[range(total_states)]*n_dirs+[[output_color]]
+for output_color,inputs in list(leaving_color_behind.items()):
+    transition = [inputs]+[list(range(total_states))]*n_dirs+[[output_color]]
     transitions += [transition]
 
 rule_name = prefix+'_'+spec_string
