@@ -229,7 +229,7 @@ def draw_line(x1, y1, x2, y2, state = 1):
     if dy < 0: sy = -1
     
     if ax > ay:
-        d = ay - (ax / 2)
+        d = ay - (ax // 2)
         while x1 != x2:
             g.setcell(x1, y1, state)
             if d >= 0:
@@ -238,7 +238,7 @@ def draw_line(x1, y1, x2, y2, state = 1):
             x1 += sx
             d += ay
     else:
-        d = ax - (ay / 2)
+        d = ax - (ay // 2)
         while y1 != y2:
             g.setcell(x1, y1, state)
             if d >= 0:
@@ -257,7 +257,7 @@ def color_text(string, extrastate):
     # convert two-state pattern to multi-state and set state to extrastate
     mlist = []
     tlist = list(t)
-    for i in xrange(0, len(tlist), 2):
+    for i in range(0, len(tlist), 2):
         mlist.append(tlist[i])
         mlist.append(tlist[i+1])
         mlist.append(extrastate)
@@ -293,17 +293,17 @@ def init_colors():
             s += 1
     
     # finally add rainbow colors in various shades (bright, pale, dark)
-    for hue in xrange(12):
+    for hue in range(12):
         if s > 255: break
         R,G,B = hsv_to_rgb(hue/12.0, 1.0, 1.0)
         g.setcolors([s, int(255*R), int(255*G), int(255*B)])
         s += 1
-    for hue in xrange(12):
+    for hue in range(12):
         if s > 255: break
         R,G,B = hsv_to_rgb(hue/12.0, 0.5, 1.0)
         g.setcolors([s, int(255*R), int(255*G), int(255*B)])
         s += 1
-    for hue in xrange(12):
+    for hue in range(12):
         if s > 255: break
         R,G,B = hsv_to_rgb(hue/12.0, 1.0, 0.5)
         g.setcolors([s, int(255*R), int(255*G), int(255*B)])
@@ -315,7 +315,7 @@ def init_colors():
 # --------------------------------------------------------------------
 
 def draw_icon_boxes(numicons, linestate):
-    for i in xrange(numicons):
+    for i in range(numicons):
         x = -1 + i*32
         y = -1
         
@@ -337,7 +337,7 @@ def draw_icon_boxes(numicons, linestate):
         
         # show state number above top row of icons
         t, twd, tht = color_text(str(i+1), linestate)
-        t.put(x + 32/2 - twd/2, y - 2 - tht)
+        t.put(x + 32//2 - twd//2, y - 2 - tht)
 
 # --------------------------------------------------------------------
 
@@ -350,16 +350,16 @@ def draw_icons(iconinfo, transparent):
     chars_per_pixel = iconinfo[3]
     colordict = iconinfo[4]
     pos = 5
-    numicons = height/width
-    for i in xrange(numicons):
+    numicons = height//width
+    for i in range(numicons):
         x = i*32
         y = 0
         if width == 15: y = 32
         if width == 7: y = 48
-        for row in xrange(width):
+        for row in range(width):
             pxls = iconinfo[pos]
             pos += 1
-            for col in xrange(width):
+            for col in range(width):
                 offset = col*chars_per_pixel
                 key = pxls[offset : offset + chars_per_pixel]
                 if not key in colordict:
@@ -377,12 +377,12 @@ def create31x31icons():
     width = 15
     middle = 7                  # middle row or column in 15x15 icon
     height = iconinfo15[1]
-    numicons = height/width
-    for i in xrange(numicons):
+    numicons = height//width
+    for i in range(numicons):
         x = i*32
         y = 32
-        for row in xrange(width):
-            for col in xrange(width):
+        for row in range(width):
+            for col in range(width):
                 state = g.getcell(x+col, y+row)
                 if state > 0:
                     if row == middle and col == middle:
@@ -438,23 +438,23 @@ def create_smaller_icons(big, small):
     # using a simple sampling algorithm
     global iconinfo15, iconinfo31
     if big == 15:
-        numicons = iconinfo15[1] / 15
+        numicons = iconinfo15[1] // 15
         ybig = 32
     else:
         # big = 31
-        numicons = iconinfo31[1] / 31
+        numicons = iconinfo31[1] // 31
         ybig = 0
     if small == 7:
         y = 48
     else:
         # small = 15
         y = 32
-    sample = big / small
-    offset = sample / 2
-    for i in xrange(numicons):
+    sample = big // small
+    offset = sample // 2
+    for i in range(numicons):
         x = i*32
-        for row in xrange(small):
-            for col in xrange(small):
+        for row in range(small):
+            for col in range(small):
                 state = g.getcell(x + offset + col*sample, ybig + offset + row*sample)
                 if state > 0:
                     g.setcell(x+col, y+row, state)
