@@ -78,7 +78,7 @@ def TriangularTransitionsToRuleTree_SplittingMethod(neighborhood,n_states,transi
     tree = RuleTree(n_states*n_states,numNeighbors[neighborhood])
     # for each transition pair, see if we can apply them both at once to a square
     for i,t1 in enumerate(transitions): # as lower
-        golly.show("Building rule tree... (pass 1 of 2: "+str(100*i/len(transitions))+"%)")
+        golly.show("Building rule tree... (pass 1 of 2: "+str(100*i//len(transitions))+"%)")
         for t2 in transitions: # as upper
             # we can only apply both rules at once if they overlap to some extent
             ### AKT: any() and isdisjoint() are not available in Python 2.3:
@@ -93,10 +93,10 @@ def TriangularTransitionsToRuleTree_SplittingMethod(neighborhood,n_states,transi
             # take the intersection of their inputs
             if neighborhood=="triangularVonNeumann":
                 tree.add_rule( [ encode(t1[0]&t2[1],t1[1]&t2[0]), # C
-                     encode(range(n_states),t1[2]), # S
-                     encode(t2[3],range(n_states)), # E
-                     encode(range(n_states),t1[3]), # W
-                     encode(t2[2],range(n_states)) ], # N
+                     encode(list(range(n_states)),t1[2]), # S
+                     encode(t2[3],list(range(n_states))), # E
+                     encode(list(range(n_states)),t1[3]), # W
+                     encode(t2[2],list(range(n_states))) ], # N
                      encode(t1[4],t2[4])[0] ) # C'
             elif neighborhood=="triangularMoore":
                 tree.add_rule( [ encode(t1[0]&t2[1],t1[1]&t2[0]), # C
@@ -105,50 +105,50 @@ def TriangularTransitionsToRuleTree_SplittingMethod(neighborhood,n_states,transi
                              encode(t1[9],t1[3]&t2[4]), # W
                              encode(t1[12]&t2[2],t2[7]), # N
                              encode(t1[6]&t2[11],t1[5]&t2[10]), # SE
-                             encode(range(n_states),t1[8]), # SW
-                             encode(t2[8],range(n_states)), # NE
+                             encode(list(range(n_states)),t1[8]), # SW
+                             encode(t2[8],list(range(n_states))), # NE
                              encode(t1[10]&t2[5],t1[11]&t2[6]) ], # NW
                            encode(t1[13],t2[13])[0] ) # C'
     # apply each transition to an individual triangle, leaving the other unchanged
     for i,t in enumerate(transitions):
-        golly.show("Building rule tree... (pass 2 of 2: "+str(100*i/len(transitions))+"%)")
+        golly.show("Building rule tree... (pass 2 of 2: "+str(100*i//len(transitions))+"%)")
         for t_1 in t[1]:
             if neighborhood=="triangularVonNeumann":
                 # as lower triangle:
                 tree.add_rule( [ encode(t[0],[t_1]), # C
-                                 encode(range(n_states),t[2]), # S
-                                 range(n_states*n_states), # E
-                                 encode(range(n_states),t[3]), # W
-                                 range(n_states*n_states) ], # N
+                                 encode(list(range(n_states)),t[2]), # S
+                                 list(range(n_states*n_states)), # E
+                                 encode(list(range(n_states)),t[3]), # W
+                                 list(range(n_states*n_states)) ], # N
                                  encode(t[4],[t_1])[0] ) # C'
                 # as upper triangle:
                 tree.add_rule( [ encode([t_1],t[0]), # C
-                                 range(n_states*n_states), # S
-                                 encode(t[3],range(n_states)), # E
-                                 range(n_states*n_states), # W
-                                 encode(t[2],range(n_states)) ], # N
+                                 list(range(n_states*n_states)), # S
+                                 encode(t[3],list(range(n_states))), # E
+                                 list(range(n_states*n_states)), # W
+                                 encode(t[2],list(range(n_states))) ], # N
                                  encode([t_1],t[4])[0] ) # C'
             elif neighborhood=="triangularMoore":
                 # as lower triangle:
                 tree.add_rule( [encode(t[0],[t_1]), # C
                     encode(t[7],t[2]), # S
-                    encode(t[4],range(n_states)), # E
+                    encode(t[4],list(range(n_states))), # E
                     encode(t[9],t[3]), # W
-                    encode(t[12],range(n_states)), # N
+                    encode(t[12],list(range(n_states))), # N
                     encode(t[6],t[5]), # SE
-                    encode(range(n_states),t[8]), # SW
-                    range(n_states*n_states), # NE
+                    encode(list(range(n_states)),t[8]), # SW
+                    list(range(n_states*n_states)), # NE
                     encode(t[10],t[11]) ], # NW
                     encode(t[13],[t_1])[0] ) # C'
                 # as upper triangle:
                 tree.add_rule( [encode([t_1],t[0]),
-                    encode(range(n_states),t[12]), # S
+                    encode(list(range(n_states)),t[12]), # S
                     encode(t[3],t[9]), # E
-                    encode(range(n_states),t[4]), # W
+                    encode(list(range(n_states)),t[4]), # W
                     encode(t[2],t[7]), # N
                     encode(t[11],t[10]), # SE
-                    range(n_states*n_states), # SW
-                    encode(t[8],range(n_states)), # NE
+                    list(range(n_states*n_states)), # SW
+                    encode(t[8],list(range(n_states))), # NE
                     encode(t[5],t[6]) ], # NW
                     encode([t_1],t[13])[0] ) # C'
 
@@ -184,11 +184,11 @@ def TriangularTransitionsToRuleTree_CheckerboardMethod(neighborhood,n_states,tra
                        encode_upper(t[2]),   # S
                        encode_upper(t[1]),   # E
                        encode_upper(t[3]),   # W
-                       range(total_states)],   # N
+                       list(range(total_states))],   # N
                       encode_lower(t[4])[0]) # C'
         # as upper
         tree.add_rule([encode_upper(t[0]),   # C
-                       range(total_states),    # S
+                       list(range(total_states)),    # S
                        encode_lower(t[3]),   # E
                        encode_lower(t[1]),   # W
                        encode_lower(t[2])],  # N
@@ -213,8 +213,8 @@ def MakeTriangularIcons_SplittingMethod(n_states,colors,force_background,rule_na
                 pixels[row][column] = background_color
             else:
                 # decide if this pixel is a lower or upper triangle
-                iState = int(column/31)
-                upper = int((iState+1) / n_states)
+                iState = int(column//31)
+                upper = int((iState+1) // n_states)
                 lower = (iState+1) - upper*n_states
                 is_upper = False
                 is_lower = False
@@ -357,13 +357,13 @@ def EmulateTriangular(neighborhood,n_states,transitions_list,input_filename):
             [68,171,194],[72,184,71],[184,71,72],[71,72,184],[169,255,188],[252,179,63],[63,252,179],
             [179,63,252],[80,9,0],[0,80,9],[9,0,80],[255,175,250],[199,134,213],[115,100,95],[188,163,0],
             [0,188,163],[163,0,188],[203,73,0],[0,203,73],[73,0,203],[94,189,0],[189,0,94]]
-        colors = dict(zip(range(len(random_colors)),random_colors))
+        colors = dict(list(zip(list(range(len(random_colors))),random_colors)))
     else:
         # read from the .colors file
         colors = {0:[0,0,0]} # background is black
         for line in cf:
             if line[0:6]=='color ':
-                entries = map(int,line[6:].replace('=',' ').replace('\n',' ').split())
+                entries = list(map(int,line[6:].replace('=',' ').replace('\n',' ').split()))
                 if len(entries)<4:
                     continue # too few entries, ignore
                 if entries[0]==0:
