@@ -1656,17 +1656,21 @@ if f then
 [[
 [M2] (golly 3.3)
 #R RainbowASOv1.3
+#C
 #C Spaceships of all unit-fraction speeds from c/1 to c/50,
-#C  with a scattering of slower speeds down to c/150.
-#C  Rules represented include B3/S23 and a wide variety
-#C  of other Life-like and isotropic non-totalistic rules.
-#C  The RainbowASOv1.3 "mashup rule" lets spaceships from 
-#C  different rules run simultaneously in the same pattern.
-#C Rule created and pattern compiled by muzik, 9 July 2017, with 
-#C  hyperbolic spaceship stunt-flying arrangement by Adam P. Goucher.
+#C with a scattering of slower speeds down to c/150.
+#C Rules represented include B3/S23 and a wide variety
+#C of other Life-like and isotropic non-totalistic rules.
+#C The RainbowASOv1.3 "mashup rule" lets spaceships from 
+#C different rules run simultaneously in the same pattern.
+#C
+#C Rule created and pattern compiled by Connor Steppie, 9 July 2017, 
+#C with hyperbolic spaceship stunt-flying arrangement by
+#C Adam P. Goucher.
 #C http://www.conwaylife.com/forums/viewtopic.php?p=46271#p46271
-#C A more recent version of the RainbowASO rule, also by muzik,
-#C  can be found here (RainbowASOv3.1, 6 July 2018):
+#C
+#C A more recent version of the RainbowASO rule, also by
+#C Connor Steppie, can be found here (RainbowASOv3.1, 6 July 2018):
 #C http://www.conwaylife.com/forums/viewtopic.php?p=61655#p61655
 1 0 0 0 35
 2 0 1 0 0
